@@ -2,11 +2,12 @@
 # vim:se tw=79 sts=4 ts=4 et ai fileencoding=utf-8 :
 
 """
-IMEDIFF - an Interactive Merge Editor for DIFF2 and DIFF3
-          Curses based single-pane fullscreen tool
+IMEDIFF - Interactive Merge Editor for DIFF2 and DIFF3
+          Curses based single-pane fullscreen interactive tool
+          and CLI based non-interactive tool with --macro
 
 Copyright (C) 2003, 2004 Jarno Elonen <elonen@iki.fi>
-Copyright (C) 2018       Osamu Aoki <osamu@debian.org>
+Copyright (C) 2018--2024 Osamu Aoki <osamu@debian.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -23,4 +24,4 @@ License along with this program; if not, write to the Free
 Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 Boston, MA 02110-1301, USA.
 """
-from imediff.__main__ import *
+from .__main__ import *
