@@ -2,11 +2,12 @@
 # vim:se tw=79 sts=4 ts=4 et ai fileencoding=utf-8 :
 
 """
-IMEDIFF - an Interactive Merge Editor for DIFF2 and DIFF3
-          Curses based single-pane fullscreen tool
+IMEDIFF - Interactive Merge Editor for DIFF2 and DIFF3
+          Curses based single-pane fullscreen interactive tool
+          and CLI based non-interactive tool with --macro
 
 Copyright (C) 2003, 2004 Jarno Elonen <elonen@iki.fi>
-Copyright (C) 2018-2021  Osamu Aoki <osamu@debian.org>
+Copyright (C) 2018--2024 Osamu Aoki <osamu@debian.org>
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License as
@@ -26,9 +27,9 @@ Boston, MA 02110-1301, USA.
 
 import curses
 
-from imediff.utils import _, console_width, error_exit, logger, write_file
-from imediff.config import cc
-from imediff.cli import *
+from .utils import _, console_width, error_exit, logger, write_file
+from .config import cc
+from .cli import *
 
 # Format stings
 _helptext2 = _(
@@ -134,7 +135,7 @@ Quick start:
 
 ---------------------------------------------------------------------------
     Tutorial for imediff (Interactive Merge Editor)
-                        Copyright (C) 2021 Osamu Aoki <osamu@debian.org>
+                        Copyright (C) 2024 Osamu Aoki <osamu@debian.org>
 ---------------------------------------------------------------------------
 
 The imediff command helps you to merge 2 slightly different files with an
@@ -606,6 +607,12 @@ class TextPad(TextData):  # TUI data
             contw += 2  # for the tag indicator + ' '
         self.conth = conth
         self.contw = contw
+        # log before possible crash
+        logger.debug(
+            "===  Before calling self.curses.newpad({}, {})".format(
+                self.conth + 1, max(80, contw + 1)
+            )
+        )
         # actual textpad size slightly bigger for safety margin
         self.textpad = curses.newpad(conth + 1, max(80, contw + 1))
         for i in range(len(self.opcodes)):
